"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dot = require("dot-prop");
const path = require("path");
const readPkgUp = require("read-pkg-up");
exports.flags = {
    dev: {
        alias: "D",
        type: "boolean",
    },
    open: {
        alias: "o",
        type: "boolean",
    },
    outDir: {
        alias: "d",
        type: "string",
    },
    port: {
        alias: "p",
        type: "string",
    },
    basePath: {
        type: "string",
    },
};
exports.getServerBasePath = (text) => {
    if (!text) {
        return "/";
    }
    if (text.startsWith("/")) {
        return text.trim();
    }
    return path.join("/", text).trim();
};
exports.parser = (cli) => {
    const [source = process.cwd()] = cli.input;
    const inputFlags = cli.flags;
    const pkg = readPkgUp.sync({ cwd: source }) || {};
    const commonOption = {
        source,
        destination: inputFlags.outDir ? path.join(process.cwd(), inputFlags.outDir) : undefined,
        serverBasePath: exports.getServerBasePath(inputFlags.basePath),
        blacklist: {
            extensions: [".mdx"],
        },
    };
    if (inputFlags.dev) {
        return {
            develop: {
                open: true,
                ...commonOption,
                ...dot.get(pkg, "pkg.rocu"),
            },
        };
    }
    else {
        return {
            build: { ...commonOption, ...dot.get(pkg, "pkg.rocu") },
        };
    }
};
